/**
 * Author: S. Smith
 * Revised: March 17, 2009
 * 
 * Description: Testing EdgeT Class
 */

import org.junit.*;
import static org.junit.Assert.*;
import static java.lang.Math.*;

public class TestEdgeT
{
   private static double ADMISS_ERR_DIST = 1e-20;

   @Test
   public void testConstructorForNode1()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     assertEquals(true, n1.equal(e.node1()));
   }

   @Test
   public void testConstructorForNode2()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     assertEquals(true, n2.equal(e.node2()));
   }

   @Test
   public void testLength()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     assertEquals(sqrt(2), e.length(), ADMISS_ERR_DIST);
   }

   @Test
   public void testHorizontalYes()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     assertEquals(true, e.is_horizontal());
   }

   @Test
   public void testHorizontalNo()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     assertEquals(false, e.is_horizontal());
   }

   @Test
   public void testEqualYes1()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     EdgeT e2 = new EdgeT(n1, n2);
     assertEquals(true, e1.equal(e2));
   }

   @Test
   public void testEqualYes2()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     EdgeT e2 = new EdgeT(n2, n1);
     assertEquals(true, e1.equal(e2));
   }

   @Test
   public void testEqualNo()
   {
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     EdgeT e2 = new EdgeT(n1, n1);
     assertEquals(false, e1.equal(e2));
   }

}
