/**
 * Author: S. Smith
 * Revised: March 14, 2008
 * 
 * Description: Testing Map Class
 */

import org.junit.*;
import static org.junit.Assert.*;

public class TestMap
{

   @Test 
   public void testInit() //checking for correct syntax, absence of exceptions
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     assertEquals(false, Map.contains(e));
   }

   @Test 
   public void testAdd1()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     Map.add(e);
     assertEquals(true, Map.contains(e));
   }

   @Test 
   public void testAdd2()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     NodeT n3 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n4 = new NodeT(1.0, 15.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e2 = new EdgeT(n3, n4);
     Map.add(e1);
     Map.add(e2);
     assertEquals(true, Map.contains(e1) && Map.contains(e2));
   }

   @Test 
   public void testAdd3()
   {
     int MAX = 10;
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);

     Map.init();
     for (int i = 0; i < MAX; i++)
     {
       n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
       n2 = new NodeT(i, i, NodeT.nodeTypeT.JUNCTION);
       e = new EdgeT(n1, n2);       
       Map.add(e);
     }
     assertEquals(true, Map.contains(e));
   }

   @Test (expected=ALREADY_IN_MAP.class)
   public void testForExceptionALREADY1()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);
     Map.add(e);
     Map.add(e);   
   }

   @Test (expected=ALREADY_IN_MAP.class)
   public void testForExceptionALREADY2()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     Map.add(e1);
     EdgeT e2 = new EdgeT(n2, n1);
     Map.add(e2);   
   }

   @Test 
   public void testDel1()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     NodeT n3 = new NodeT(1.0, 1.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n4 = new NodeT(1.0, 15.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e2 = new EdgeT(n3, n4);
     Map.add(e1);
     Map.add(e2);
     Map.del(e1);
     assertEquals(true, Map.contains(e2) && !Map.contains(e1));
   }

   @Test 
   public void testDel2()
   {
     int MAX = 10;
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);

     Map.init();
     for (int i = 0; i < MAX; i++)
     {
       n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
       n2 = new NodeT(i, i, NodeT.nodeTypeT.JUNCTION);
       e = new EdgeT(n1, n2);       
       Map.add(e);
     }

     n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     n2 = new NodeT(2, 2, NodeT.nodeTypeT.JUNCTION);
     e = new EdgeT(n1, n2);       
    
     Map.del(e);

     assertEquals(true, !Map.contains(e));
   }

   @Test (expected=NOT_IN_MAP.class)
   public void testForExceptionNOT()
   {
     int MAX = 10;
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e = new EdgeT(n1, n2);

     Map.init();
     for (int i = 0; i < MAX; i++)
     {
       n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
       n2 = new NodeT(i, i, NodeT.nodeTypeT.JUNCTION);
       e = new EdgeT(n1, n2);       
       Map.add(e);
     }

     n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     n2 = new NodeT(2, 2, NodeT.nodeTypeT.JUNCTION);
     e = new EdgeT(n1, n2);       
    
     Map.del(e);
     Map.del(e);
   }

   @Test 
   public void testContainsYes()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     Map.add(e1);
     n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     n2 = new NodeT(23.0, 23.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e2 = new EdgeT(n1, n2);
     Map.add(e2);
     assertEquals(true, Map.contains(e1));
   }

   @Test 
   public void testContainsNo()
   {
     Map.init();
     NodeT n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     NodeT n2 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e1 = new EdgeT(n1, n2);
     Map.add(e1);
     n1 = new NodeT(0.0, 0.0, NodeT.nodeTypeT.JUNCTION);
     n2 = new NodeT(23.0, 23.0, NodeT.nodeTypeT.JUNCTION);
     EdgeT e2 = new EdgeT(n1, n2);
     assertEquals(true, !Map.contains(e2));
   }

}
